from seven_top.top.api.rest.OpentradeCreateOrderRequest import OpentradeCreateOrderRequest
from seven_top.top.api.rest.AlibabaAliqinTaNumberSinglecallbyttsRequest import AlibabaAliqinTaNumberSinglecallbyttsRequest
from seven_top.top.api.rest.SkusCustomGetRequest import SkusCustomGetRequest
from seven_top.top.api.rest.JstSmsOfficialaccountReportRequest import JstSmsOfficialaccountReportRequest
from seven_top.top.api.rest.TmcMessageProduceRequest import TmcMessageProduceRequest
from seven_top.top.api.rest.ItemsCustomGetRequest import ItemsCustomGetRequest
from seven_top.top.api.rest.FuwuSaleLinkGenRequest import FuwuSaleLinkGenRequest
from seven_top.top.api.rest.AlibabaAliqinTaNumberSinglecallbyvoiceRequest import AlibabaAliqinTaNumberSinglecallbyvoiceRequest
from seven_top.top.api.rest.ItemSellerGetRequest import ItemSellerGetRequest
from seven_top.top.api.rest.KfcKeywordSearchRequest import KfcKeywordSearchRequest
from seven_top.top.api.rest.JstSmsMessageDirectBatchsendRequest import JstSmsMessageDirectBatchsendRequest
from seven_top.top.api.rest.TmcMessagesProduceRequest import TmcMessagesProduceRequest
from seven_top.top.api.rest.SubuserDepartmentsGetRequest import SubuserDepartmentsGetRequest
from seven_top.top.api.rest.RefundGetRequest import RefundGetRequest
from seven_top.top.api.rest.OpenuidGetRequest import OpenuidGetRequest
from seven_top.top.api.rest.RefundsReceiveGetRequest import RefundsReceiveGetRequest
from seven_top.top.api.rest.MiniappTemplateUpdateRequest import MiniappTemplateUpdateRequest
from seven_top.top.api.rest.ItemsOnsaleGetRequest import ItemsOnsaleGetRequest
from seven_top.top.api.rest.SellercenterSubusersGetRequest import SellercenterSubusersGetRequest
from seven_top.top.api.rest.MiniappTemplateQueryappRequest import MiniappTemplateQueryappRequest
from seven_top.top.api.rest.FuwuScoresGetRequest import FuwuScoresGetRequest
from seven_top.top.api.rest.RefundMessageAddRequest import RefundMessageAddRequest
from seven_top.top.api.rest.ItempropvaluesGetRequest import ItempropvaluesGetRequest
from seven_top.top.api.rest.MiniappTemplateOnlineappRequest import MiniappTemplateOnlineappRequest
from seven_top.top.api.rest.FilesGetRequest import FilesGetRequest
from seven_top.top.api.rest.TopAuthTokenCreateRequest import TopAuthTokenCreateRequest
from seven_top.top.api.rest.TmcMessagesConsumeRequest import TmcMessagesConsumeRequest
from seven_top.top.api.rest.MiniappShorturlCreateRequest import MiniappShorturlCreateRequest
from seven_top.top.api.rest.SellercenterRolesGetRequest import SellercenterRolesGetRequest
from seven_top.top.api.rest.VasSubscSearchRequest import VasSubscSearchRequest
from seven_top.top.api.rest.MiniappTemplateRollbackRequest import MiniappTemplateRollbackRequest
from seven_top.top.api.rest.ItemcatsGetRequest import ItemcatsGetRequest
from seven_top.top.api.rest.SellercatsListGetRequest import SellercatsListGetRequest
from seven_top.top.api.rest.AlibabaBeneiftDrawRequest import AlibabaBeneiftDrawRequest
from seven_top.top.api.rest.AlibabaAliqinTaSmsNumSendRequest import AlibabaAliqinTaSmsNumSendRequest
from seven_top.top.api.rest.RefundRefuseRequest import RefundRefuseRequest
from seven_top.top.api.rest.JstSmsOfficialaccountOnlineRequest import JstSmsOfficialaccountOnlineRequest
from seven_top.top.api.rest.JstSmsOfficialaccountCancelRequest import JstSmsOfficialaccountCancelRequest
from seven_top.top.api.rest.RefundsApplyGetRequest import RefundsApplyGetRequest
from seven_top.top.api.rest.JstSmsMessageSendRequest import JstSmsMessageSendRequest
from seven_top.top.api.rest.TopIpoutGetRequest import TopIpoutGetRequest
from seven_top.top.api.rest.TmcGroupDeleteRequest import TmcGroupDeleteRequest
from seven_top.top.api.rest.ShopSellerGetRequest import ShopSellerGetRequest
from seven_top.top.api.rest.SellercenterUserPermissionsGetRequest import SellercenterUserPermissionsGetRequest
from seven_top.top.api.rest.JstSmsMessageShorturlQueryRequest import JstSmsMessageShorturlQueryRequest
from seven_top.top.api.rest.CrmMemberIdentityGetRequest import CrmMemberIdentityGetRequest
from seven_top.top.api.rest.TmcTopicGroupAddRequest import TmcTopicGroupAddRequest
from seven_top.top.api.rest.ShopcatsListGetRequest import ShopcatsListGetRequest
from seven_top.top.api.rest.TmcGroupsGetRequest import TmcGroupsGetRequest
from seven_top.top.api.rest.CrmMemberJoinurlGetRequest import CrmMemberJoinurlGetRequest
from seven_top.top.api.rest.VasOrderSearchRequest import VasOrderSearchRequest
from seven_top.top.api.rest.JstSmsStatusQueryRequest import JstSmsStatusQueryRequest
from seven_top.top.api.rest.HttpdnsGetRequest import HttpdnsGetRequest
from seven_top.top.api.rest.TmcTopicGroupDeleteRequest import TmcTopicGroupDeleteRequest
from seven_top.top.api.rest.MiniappTemplateOfflineappRequest import MiniappTemplateOfflineappRequest
from seven_top.top.api.rest.AlibabaBenefitQueryRequest import AlibabaBenefitQueryRequest
from seven_top.top.api.rest.AppipGetRequest import AppipGetRequest
from seven_top.top.api.rest.OpenTradeGetRequest import OpenTradeGetRequest
from seven_top.top.api.rest.JstSmsOaidMessageSendRequest import JstSmsOaidMessageSendRequest
from seven_top.top.api.rest.TimeGetRequest import TimeGetRequest
from seven_top.top.api.rest.TmcMessagesConfirmRequest import TmcMessagesConfirmRequest
from seven_top.top.api.rest.TopSecretGetRequest import TopSecretGetRequest
from seven_top.top.api.rest.MiniappTemplateUpdateappRequest import MiniappTemplateUpdateappRequest
from seven_top.top.api.rest.AlibabaBenefitSendRequest import AlibabaBenefitSendRequest
from seven_top.top.api.rest.ItemsSellerListGetRequest import ItemsSellerListGetRequest
from seven_top.top.api.rest.JstSmsMessageShorturlCreateRequest import JstSmsMessageShorturlCreateRequest
from seven_top.top.api.rest.SellercenterRoleAddRequest import SellercenterRoleAddRequest
from seven_top.top.api.rest.TmcUserPermitRequest import TmcUserPermitRequest
from seven_top.top.api.rest.ItempropsGetRequest import ItempropsGetRequest
from seven_top.top.api.rest.MiniappDistributionOrderItemsBindRequest import MiniappDistributionOrderItemsBindRequest
from seven_top.top.api.rest.OpenuidGetBytradeRequest import OpenuidGetBytradeRequest
from seven_top.top.api.rest.JstSmsOfficialaccountOfflineRequest import JstSmsOfficialaccountOfflineRequest
from seven_top.top.api.rest.MiniappUserInfoGetRequest import MiniappUserInfoGetRequest
from seven_top.top.api.rest.ItemcatsAuthorizeGetRequest import ItemcatsAuthorizeGetRequest
from seven_top.top.api.rest.UserSellerGetRequest import UserSellerGetRequest
from seven_top.top.api.rest.ItemsInventoryGetRequest import ItemsInventoryGetRequest
from seven_top.top.api.rest.VasSubscribeGetRequest import VasSubscribeGetRequest
from seven_top.top.api.rest.RefundMessagesGetRequest import RefundMessagesGetRequest
from seven_top.top.api.rest.ItemSkusGetRequest import ItemSkusGetRequest
from seven_top.top.api.rest.MiniappDistributionOrderCreateRequest import MiniappDistributionOrderCreateRequest
from seven_top.top.api.rest.SubuserDutysGetRequest import SubuserDutysGetRequest
from seven_top.top.api.rest.JstSmsTaskCreateRequest import JstSmsTaskCreateRequest
from seven_top.top.api.rest.SubuserInfoUpdateRequest import SubuserInfoUpdateRequest
from seven_top.top.api.rest.TmcUserCancelRequest import TmcUserCancelRequest
from seven_top.top.api.rest.MiniappItemsGetRequest import MiniappItemsGetRequest
from seven_top.top.api.rest.AlibabaAliqinTaVoiceNumDoublecallRequest import AlibabaAliqinTaVoiceNumDoublecallRequest
from seven_top.top.api.rest.TopAuthTokenRefreshRequest import TopAuthTokenRefreshRequest
from seven_top.top.api.rest.SubuserFullinfoGetRequest import SubuserFullinfoGetRequest
from seven_top.top.api.rest.TmcGroupAddRequest import TmcGroupAddRequest
from seven_top.top.api.rest.OpenlinkSessionGetRequest import OpenlinkSessionGetRequest
from seven_top.top.api.rest.MiniapppTemplateInstantiateRequest import MiniapppTemplateInstantiateRequest
from seven_top.top.api.rest.MiniappTemplateInstantiateRequest import MiniappTemplateInstantiateRequest
from seven_top.top.api.rest.ItemSkuGetRequest import ItemSkuGetRequest
from seven_top.top.api.rest.JstSmsOfficialaccountOrderRequest import JstSmsOfficialaccountOrderRequest
from seven_top.top.api.rest.TopSecretRegisterRequest import TopSecretRegisterRequest
from seven_top.top.api.rest.JstSmsMenuinfoReportRequest import JstSmsMenuinfoReportRequest
from seven_top.top.api.rest.MiniappDistributionItemsBindRequest import MiniappDistributionItemsBindRequest
from seven_top.top.api.rest.OpenuidGetBymixnickRequest import OpenuidGetBymixnickRequest
from seven_top.top.api.rest.AlibabaAliqinTaSmsNumQueryRequest import AlibabaAliqinTaSmsNumQueryRequest
from seven_top.top.api.rest.OpenTradesSoldGetRequest import OpenTradesSoldGetRequest
from seven_top.top.api.rest.TopSdkFeedbackUploadRequest import TopSdkFeedbackUploadRequest
from seven_top.top.api.rest.SellercenterSubuserPermissionsRolesGetRequest import SellercenterSubuserPermissionsRolesGetRequest
from seven_top.top.api.rest.SubusersGetRequest import SubusersGetRequest
from seven_top.top.api.rest.TmcUserGetRequest import TmcUserGetRequest
from seven_top.top.api.rest.AlibabaBenefitDrawRequest import AlibabaBenefitDrawRequest
from seven_top.top.api.rest.JstSmsExtendcodeQueryRequest import JstSmsExtendcodeQueryRequest
from seven_top.top.api.rest.AppstoreSubscribeGetRequest import AppstoreSubscribeGetRequest
from seven_top.top.api.rest.TmcAuthGetRequest import TmcAuthGetRequest
from seven_top.top.api.rest.PromotionActivityGetRequest import PromotionActivityGetRequest
from seven_top.top.api.rest.PromotionCouponsGetRequest import PromotionCouponsGetRequest
from seven_top.top.api.rest.PromotionLimitdiscountDetailGetRequest import PromotionLimitdiscountDetailGetRequest
from seven_top.top.api.rest.PromotionLimitdiscountGetRequest import PromotionLimitdiscountGetRequest
from seven_top.top.api.rest.PromotionMealGetRequest import PromotionMealGetRequest
from seven_top.top.api.rest.MarketingPromotionKfcRequest import MarketingPromotionKfcRequest
from seven_top.top.api.rest.MiniappCloudFunctionInvokeRequest import MiniappCloudFunctionInvokeRequest
from seven_top.top.api.rest.OpentradeGroupActivtiyQueryRequest import OpentradeGroupActivtiyQueryRequest
from seven_top.top.api.rest.OpentradeGroupDetailRequest import OpentradeGroupDetailRequest
from seven_top.top.api.rest.OpentradeGroupJoinRequest import OpentradeGroupJoinRequest
from seven_top.top.api.rest.OpentradeGroupMemberInfoRequest import OpentradeGroupMemberInfoRequest
from seven_top.top.api.rest.OpentradeGroupMemberInfosRequest import OpentradeGroupMemberInfosRequest
from seven_top.top.api.rest.OpentradeGroupOpenRequest import OpentradeGroupOpenRequest
from seven_top.top.api.rest.OpentradeGroupOrderRequest import OpentradeGroupOrderRequest
from seven_top.top.api.rest.OpentradeGroupQueryRequest import OpentradeGroupQueryRequest
from seven_top.top.api.rest.OpentradeGroupSyncRequest import OpentradeGroupSyncRequest
from seven_top.top.api.rest.OpentradeSpecialItemsBindRequest import OpentradeSpecialItemsBindRequest
from seven_top.top.api.rest.OpentradeSpecialItemsQueryRequest import OpentradeSpecialItemsQueryRequest
from seven_top.top.api.rest.OpentradeSpecialItemsUnbindRequest import OpentradeSpecialItemsUnbindRequest
from seven_top.top.api.rest.OpentradeSpecialRuleUpdateRequest import OpentradeSpecialRuleUpdateRequest
from seven_top.top.api.rest.OpentradeSpecialUsersMarkRequest import OpentradeSpecialUsersMarkRequest
from seven_top.top.api.rest.OpentradeSpecialUsersQueryRequest import OpentradeSpecialUsersQueryRequest
from seven_top.top.api.rest.OpentradeToolsItemsBindRequest import OpentradeToolsItemsBindRequest
from seven_top.top.api.rest.OpentradeToolsItemsQueryRequest import OpentradeToolsItemsQueryRequest
from seven_top.top.api.rest.OpentradeToolsItemsUnbindRequest import OpentradeToolsItemsUnbindRequest
from seven_top.top.api.rest.TmallTraderateFeedsGetRequest import TmallTraderateFeedsGetRequest
from seven_top.top.api.rest.TmallTraderateItemtagsGetRequest import TmallTraderateItemtagsGetRequest
from seven_top.top.api.rest.TraderateImprImprwordsGetRequest import TraderateImprImprwordsGetRequest
from seven_top.top.api.rest.TraderatesGetRequest import TraderatesGetRequest
from seven_top.top.api.rest.MiniappCloudMongoUpdateRequest import MiniappCloudMongoUpdateRequest
from seven_top.top.api.rest.MiniappCloudMongoInsertRequest import MiniappCloudMongoInsertRequest
from seven_top.top.api.rest.OpenuidChangeRequest import OpenuidChangeRequest
from seven_top.top.api.rest.SellercenterRoleInfoGetRequest import SellercenterRoleInfoGetRequest
from seven_top.top.api.rest.SellercenterRolemembersGetRequest import SellercenterRolemembersGetRequest
from seven_top.top.api.rest.SubuserEmployeeAddRequest import SubuserEmployeeAddRequest
from seven_top.top.api.rest.JstSmsMessageBatchsendRequest import JstSmsMessageBatchsendRequest
from seven_top.top.api.rest.JstMiniappCrowdCreateRequest import JstMiniappCrowdCreateRequest
from seven_top.top.api.rest.JstMiniappCrowdMessageSendRequest import JstMiniappCrowdMessageSendRequest
from seven_top.top.api.rest.JstMiniappOpenidMessageSendRequest import JstMiniappOpenidMessageSendRequest
from seven_top.top.api.rest.MiniappAppSellerConfigCompleteRequest import MiniappAppSellerConfigCompleteRequest
from seven_top.top.api.rest.AlibabaShopCouponApplyRequest import AlibabaShopCouponApplyRequest
from seven_top.top.api.rest.AlibabaLafiteSellerActivityListRequest import AlibabaLafiteSellerActivityListRequest
from seven_top.top.api.rest.AlibabaLatourStrategyShowRequest import AlibabaLatourStrategyShowRequest
from seven_top.top.api.rest.AlibabaLafiteSellerBenefitListRequest import AlibabaLafiteSellerBenefitListRequest
from seven_top.top.api.rest.AlibabaLatourStrategyIssueRequest import AlibabaLatourStrategyIssueRequest
from seven_top.top.api.rest.CrmPointAvailableGetRequest import CrmPointAvailableGetRequest
from seven_top.top.api.rest.CrmPointAvailableGetPrivyCpRequest import CrmPointAvailableGetPrivyCpRequest
from seven_top.top.api.rest.CrmPointChangePrivyRequest import CrmPointChangePrivyRequest
from seven_top.top.api.rest.CrmPointChangeRequest import CrmPointChangeRequest
from seven_top.top.api.rest.CrmMemberIdentityGetPrivyRequest import CrmMemberIdentityGetPrivyRequest
from seven_top.top.api.rest.MiniappDistributionOrderPrecreateRequest import MiniappDistributionOrderPrecreateRequest
from seven_top.top.api.rest.MiniappDistributionOrderItemsAllBindRequest import MiniappDistributionOrderItemsAllBindRequest
from seven_top.top.api.rest.MiniappDistributionOrderGetRequest import MiniappDistributionOrderGetRequest
from seven_top.top.api.rest.MiniappDistributionMaterialUpdateRequest import MiniappDistributionMaterialUpdateRequest
from seven_top.top.api.rest.MiniappDistributionMaterialGetRequest import MiniappDistributionMaterialGetRequest
from seven_top.top.api.rest.MiniappDistributionMaterialDeleteRequest import MiniappDistributionMaterialDeleteRequest
from seven_top.top.api.rest.MiniappDistributionMaterialCreateRequest import MiniappDistributionMaterialCreateRequest
from seven_top.top.api.rest.MiniappInteractBenefitItemGetRequest import MiniappInteractBenefitItemGetRequest
from seven_top.top.api.rest.JstSmsTemplateReportRequest import JstSmsTemplateReportRequest
from seven_top.top.api.rest.JstSmsTemplateQueryRequest import JstSmsTemplateQueryRequest
from seven_top.top.api.rest.JstSmsTemplateModifyRequest import JstSmsTemplateModifyRequest
from seven_top.top.api.rest.JstSmsTemplateDeleteRequest import JstSmsTemplateDeleteRequest
from seven_top.top.api.rest.JstSmsTemplateCreateRequest import JstSmsTemplateCreateRequest
from seven_top.top.api.rest.JstSmsSignnameReportRequest import JstSmsSignnameReportRequest
from seven_top.top.api.rest.JstSmsSignnameQueryRequest import JstSmsSignnameQueryRequest
from seven_top.top.api.rest.JstSmsSignnameModifyRequest import JstSmsSignnameModifyRequest
from seven_top.top.api.rest.JstSmsSignnameDeleteRequest import JstSmsSignnameDeleteRequest
from seven_top.top.api.rest.JstSmsSignnameCreateRequest import JstSmsSignnameCreateRequest
from seven_top.top.api.rest.ChattingPlatformNewuserUserGroupListRequest import ChattingPlatformNewuserUserGroupListRequest
from seven_top.top.api.rest.ChattingPlatformNewuserUserJoinGroupInfoRequest import ChattingPlatformNewuserUserJoinGroupInfoRequest
from seven_top.top.api.rest.MiniappWidgetTemplateInstanceQueryRequest import MiniappWidgetTemplateInstanceQueryRequest
from seven_top.top.api.rest.MiniappWidgetTemplateInstanceUpdateRequest import MiniappWidgetTemplateInstanceUpdateRequest
from seven_top.top.api.rest.MiniappWidgetTemplateInstantiateRequest import MiniappWidgetTemplateInstantiateRequest
from seven_top.top.api.rest.SellercenterSubusersPageRequest import SellercenterSubusersPageRequest
from seven_top.top.api.rest.SubusersInfoQueryRequest import SubusersInfoQueryRequest
from seven_top.top.api.rest.SubusersPageRequest import SubusersPageRequest
from seven_top.top.api.rest.SubusersSubaccountSearchRequest import SubusersSubaccountSearchRequest
# CRM接口
from seven_top.top.api.rest.OpencrmCrowdinstStatusGetRequest import OpencrmCrowdinstStatusGetRequest
from seven_top.top.api.rest.OpencrmCrowdanalysisQueryRequest import OpencrmCrowdanalysisQueryRequest
from seven_top.top.api.rest.OpencrmCtagUploadSingleCountRequest import OpencrmCtagUploadSingleCountRequest
from seven_top.top.api.rest.OpencrmMexRightQueryRequest import OpencrmMexRightQueryRequest
from seven_top.top.api.rest.OpencrmCrowdsSystemQueryRequest import OpencrmCrowdsSystemQueryRequest
from seven_top.top.api.rest.OpencrmCrowdinstCreateRequest import OpencrmCrowdinstCreateRequest
from seven_top.top.api.rest.OpencrmRuleinstanceAddRequest import OpencrmRuleinstanceAddRequest
from seven_top.top.api.rest.CrmGroupAppendRequest import CrmGroupAppendRequest
from seven_top.top.api.rest.CrmGradeGetRequest import CrmGradeGetRequest
from seven_top.top.api.rest.OpencrmStrategyTemplateListRequest import OpencrmStrategyTemplateListRequest
from seven_top.top.api.rest.OpencrmCversionCardtplQueryRequest import OpencrmCversionCardtplQueryRequest
from seven_top.top.api.rest.OpencrmBenefitGradeSaveRequest import OpencrmBenefitGradeSaveRequest
from seven_top.top.api.rest.OpencrmCommercialRelationQueryRequest import OpencrmCommercialRelationQueryRequest
from seven_top.top.api.rest.OpencrmRuleQueryRequest import OpencrmRuleQueryRequest
from seven_top.top.api.rest.OpencrmTmcsSuppliersRequest import OpencrmTmcsSuppliersRequest
from seven_top.top.api.rest.OpencrmCversionTemplateUpdateRequest import OpencrmCversionTemplateUpdateRequest
from seven_top.top.api.rest.OpencrmActivityCouponsQueryRequest import OpencrmActivityCouponsQueryRequest
from seven_top.top.api.rest.OpencrmDatabankBrandAuthQueryRequest import OpencrmDatabankBrandAuthQueryRequest
from seven_top.top.api.rest.CrmGrouptaskCheckRequest import CrmGrouptaskCheckRequest
from seven_top.top.api.rest.OpencrmRuleinstanceQueryRequest import OpencrmRuleinstanceQueryRequest
from seven_top.top.api.rest.OpencrmStrategyInstEventStopRequest import OpencrmStrategyInstEventStopRequest
from seven_top.top.api.rest.OpencrmDigitalSmsSingleSendRequest import OpencrmDigitalSmsSingleSendRequest
from seven_top.top.api.rest.OpencrmDatabankCrowdSyncRequest import OpencrmDatabankCrowdSyncRequest
from seven_top.top.api.rest.CrmGradeSetRequest import CrmGradeSetRequest
from seven_top.top.api.rest.OpencrmSmsSinglePostRequest import OpencrmSmsSinglePostRequest
from seven_top.top.api.rest.OpencrmBenefitGradeQueryRequest import OpencrmBenefitGradeQueryRequest
from seven_top.top.api.rest.OpencrmCrowdinstLiteUploadBachRequest import OpencrmCrowdinstLiteUploadBachRequest
from seven_top.top.api.rest.OpencrmIsvtagGetRequest import OpencrmIsvtagGetRequest
from seven_top.top.api.rest.OpencrmCtagUploadPrivyRequest import OpencrmCtagUploadPrivyRequest
from seven_top.top.api.rest.OpencrmSellerBlacklistAdddeleteRequest import OpencrmSellerBlacklistAdddeleteRequest
from seven_top.top.api.rest.OpencrmSmsCrowdSendRequest import OpencrmSmsCrowdSendRequest
from seven_top.top.api.rest.PicturePicturesCountRequest import PicturePicturesCountRequest
from seven_top.top.api.rest.OpencrmExtStrategyOperationRequest import OpencrmExtStrategyOperationRequest
from seven_top.top.api.rest.OpencrmMemberSellerFetchstatusRequest import OpencrmMemberSellerFetchstatusRequest
from seven_top.top.api.rest.OpencrmIsvtagUnsubscribeRequest import OpencrmIsvtagUnsubscribeRequest
from seven_top.top.api.rest.TmallMeiCrmMemberSyncRequest import TmallMeiCrmMemberSyncRequest
from seven_top.top.api.rest.OpencrmSignatureAdddeleteRequest import OpencrmSignatureAdddeleteRequest
from seven_top.top.api.rest.OpencrmAnalysistaskCreateupdateRequest import OpencrmAnalysistaskCreateupdateRequest
from seven_top.top.api.rest.CrmShopvipCancelRequest import CrmShopvipCancelRequest
from seven_top.top.api.rest.CrmGroupAddRequest import CrmGroupAddRequest
from seven_top.top.api.rest.FuwuPurchaseOrderConfirmRequest import FuwuPurchaseOrderConfirmRequest
from seven_top.top.api.rest.OpencrmDatabankBrandsRequest import OpencrmDatabankBrandsRequest
from seven_top.top.api.rest.OpencrmCrowdanalysisGetreportRequest import OpencrmCrowdanalysisGetreportRequest
from seven_top.top.api.rest.TradeSimpleGetRequest import TradeSimpleGetRequest
from seven_top.top.api.rest.OpencrmGradeBatchaddRequest import OpencrmGradeBatchaddRequest
from seven_top.top.api.rest.OpencrmShopDecorationQueryRequest import OpencrmShopDecorationQueryRequest
from seven_top.top.api.rest.CrmGroupUpdateRequest import CrmGroupUpdateRequest
from seven_top.top.api.rest.OpencrmCrowdinstSaveascrowdRequest import OpencrmCrowdinstSaveascrowdRequest
from seven_top.top.api.rest.OpencrmTemplateUpdateRequest import OpencrmTemplateUpdateRequest
from seven_top.top.api.rest.CrmMembersGroupsBatchdeletePrivyRequest import CrmMembersGroupsBatchdeletePrivyRequest
from seven_top.top.api.rest.OpencrmCardCreateupdateRequest import OpencrmCardCreateupdateRequest
from seven_top.top.api.rest.OpencrmRulecfgUpdateRequest import OpencrmRulecfgUpdateRequest
from seven_top.top.api.rest.OpencrmRuleCafullruleRequest import OpencrmRuleCafullruleRequest
from seven_top.top.api.rest.OpencrmMemberGetOmidRequest import OpencrmMemberGetOmidRequest
from seven_top.top.api.rest.PictureUserinfoGetRequest import PictureUserinfoGetRequest
from seven_top.top.api.rest.PictureGetRequest import PictureGetRequest
from seven_top.top.api.rest.JushitaJdpUserAddRequest import JushitaJdpUserAddRequest
from seven_top.top.api.rest.TradesSimpleSoldIncrementGetRequest import TradesSimpleSoldIncrementGetRequest
from seven_top.top.api.rest.OpencrmRuleinstanceStatusUpdateRequest import OpencrmRuleinstanceStatusUpdateRequest
from seven_top.top.api.rest.OpencrmCouponQueryRequest import OpencrmCouponQueryRequest
from seven_top.top.api.rest.OpencrmCtagUploadCrowdCreateRequest import OpencrmCtagUploadCrowdCreateRequest
from seven_top.top.api.rest.OpencrmNodeFilterRequest import OpencrmNodeFilterRequest
from seven_top.top.api.rest.OpencrmCrowdinstLiteUploadFinishRequest import OpencrmCrowdinstLiteUploadFinishRequest
from seven_top.top.api.rest.CrmMembersIncrementGetRequest import CrmMembersIncrementGetRequest
from seven_top.top.api.rest.CrmMembersGetRequest import CrmMembersGetRequest
from seven_top.top.api.rest.OpencrmCardResourceGetRequest import OpencrmCardResourceGetRequest
from seven_top.top.api.rest.PictureCategoryGetRequest import PictureCategoryGetRequest
from seven_top.top.api.rest.OpencrmCrowdsQueryRequest import OpencrmCrowdsQueryRequest
from seven_top.top.api.rest.CrmMemberOuidGetRequest import CrmMemberOuidGetRequest
from seven_top.top.api.rest.OpencrmSignatureQueryPaasRequest import OpencrmSignatureQueryPaasRequest
from seven_top.top.api.rest.OpencrmCommercialChargeEstimateRequest import OpencrmCommercialChargeEstimateRequest
from seven_top.top.api.rest.OpencrmTemplateAdddeletePaasRequest import OpencrmTemplateAdddeletePaasRequest
from seven_top.top.api.rest.OpencrmCrowdUploadBachPrivyRequest import OpencrmCrowdUploadBachPrivyRequest
from seven_top.top.api.rest.OpencrmCardStrategyListQueryRequest import OpencrmCardStrategyListQueryRequest
from seven_top.top.api.rest.OpencrmSystemTemplateGetRequest import OpencrmSystemTemplateGetRequest
from seven_top.top.api.rest.CrmIndexEffectDataGetRequest import CrmIndexEffectDataGetRequest
from seven_top.top.api.rest.OpencrmCardEstimateNumberRequest import OpencrmCardEstimateNumberRequest
from seven_top.top.api.rest.CrmMemberinfoUpdateRequest import CrmMemberinfoUpdateRequest
from seven_top.top.api.rest.OpencrmSmsPostRequest import OpencrmSmsPostRequest
from seven_top.top.api.rest.OpencrmIsvtagSubscribeRequest import OpencrmIsvtagSubscribeRequest
from seven_top.top.api.rest.FuwuSpBillreordAddRequest import FuwuSpBillreordAddRequest
from seven_top.top.api.rest.OpencrmIsvtagCreateRequest import OpencrmIsvtagCreateRequest
from seven_top.top.api.rest.CrmMembersGroupsBatchdeleteRequest import CrmMembersGroupsBatchdeleteRequest
from seven_top.top.api.rest.OpencrmCtagUploadRequest import OpencrmCtagUploadRequest
from seven_top.top.api.rest.OpencrmNodereportGetRequest import OpencrmNodereportGetRequest
from seven_top.top.api.rest.OpencrmTesttmcSendRequest import OpencrmTesttmcSendRequest
from seven_top.top.api.rest.OpencrmStrategyActivityListRequest import OpencrmStrategyActivityListRequest
from seven_top.top.api.rest.OpencrmRuleExeruleRequest import OpencrmRuleExeruleRequest
from seven_top.top.api.rest.OpencrmMemadPointdataQueryRequest import OpencrmMemadPointdataQueryRequest
from seven_top.top.api.rest.OpencrmRuleAddRequest import OpencrmRuleAddRequest
from seven_top.top.api.rest.OpencrmStrategyInstConfigUpdateRequest import OpencrmStrategyInstConfigUpdateRequest
from seven_top.top.api.rest.CrmServiceChannelShortlinkCreateRequest import CrmServiceChannelShortlinkCreateRequest
from seven_top.top.api.rest.TmallCrmMemberPointChangeRequest import TmallCrmMemberPointChangeRequest
from seven_top.top.api.rest.OpencrmGradeStatusSwitchRequest import OpencrmGradeStatusSwitchRequest
from seven_top.top.api.rest.OpencrmDatabankBrandAuthRequest import OpencrmDatabankBrandAuthRequest
from seven_top.top.api.rest.OpencrmCardSmsSingleSendRequest import OpencrmCardSmsSingleSendRequest
from seven_top.top.api.rest.CrmMembersSearchRequest import CrmMembersSearchRequest
from seven_top.top.api.rest.OpencrmSignatureQueryRequest import OpencrmSignatureQueryRequest
from seven_top.top.api.rest.CrmMembersSearchPrivyRequest import CrmMembersSearchPrivyRequest
from seven_top.top.api.rest.OpencrmAllDomainCrowdCreateRequest import OpencrmAllDomainCrowdCreateRequest
from seven_top.top.api.rest.OpencrmActionCreateupdateRequest import OpencrmActionCreateupdateRequest
from seven_top.top.api.rest.OpencrmIsvtagAttrCreateupdateRequest import OpencrmIsvtagAttrCreateupdateRequest
from seven_top.top.api.rest.OpencrmExtStrategyQueryRequest import OpencrmExtStrategyQueryRequest
from seven_top.top.api.rest.OpencrmRuleBatchaddRequest import OpencrmRuleBatchaddRequest
from seven_top.top.api.rest.OpencrmCommercialRelationOpenRequest import OpencrmCommercialRelationOpenRequest
from seven_top.top.api.rest.TradesSimpleSoldGetRequest import TradesSimpleSoldGetRequest
from seven_top.top.api.rest.OpencrmStrategyVipcustomergradeGetRequest import OpencrmStrategyVipcustomergradeGetRequest
from seven_top.top.api.rest.OpencrmCardEffectDataYtxRequest import OpencrmCardEffectDataYtxRequest
from seven_top.top.api.rest.OpencrmCtagUploadBatchCountRequest import OpencrmCtagUploadBatchCountRequest
from seven_top.top.api.rest.OpencrmSmsConstInfoBuildRequest import OpencrmSmsConstInfoBuildRequest
from seven_top.top.api.rest.CrmIndexEffectivieDataGetRequest import CrmIndexEffectivieDataGetRequest
from seven_top.top.api.rest.OpencrmCrowdUpdateRequest import OpencrmCrowdUpdateRequest
from seven_top.top.api.rest.CrmMemberGroupGetPrivyRequest import CrmMemberGroupGetPrivyRequest
from seven_top.top.api.rest.CrmMembersGetPrivyRequest import CrmMembersGetPrivyRequest
from seven_top.top.api.rest.OpencrmCrowdinstSplitRequest import OpencrmCrowdinstSplitRequest
from seven_top.top.api.rest.AlipayXiaodaiUserPermitRequest import AlipayXiaodaiUserPermitRequest
from seven_top.top.api.rest.OpencrmSmsSellerTplApplyRequest import OpencrmSmsSellerTplApplyRequest
from seven_top.top.api.rest.OpencrmOrderRecordDeleteRequest import OpencrmOrderRecordDeleteRequest
from seven_top.top.api.rest.OpencrmOrderRecordAddRequest import OpencrmOrderRecordAddRequest
from seven_top.top.api.rest.CrmGroupsGetRequest import CrmGroupsGetRequest
from seven_top.top.api.rest.OpencrmAllDomainCrowdFinishRequest import OpencrmAllDomainCrowdFinishRequest
from seven_top.top.api.rest.PictureCategoryUpdateRequest import PictureCategoryUpdateRequest
from seven_top.top.api.rest.OpencrmCardSmsCrowdSendRequest import OpencrmCardSmsCrowdSendRequest
from seven_top.top.api.rest.OpencrmCrowdCheckRequest import OpencrmCrowdCheckRequest
from seven_top.top.api.rest.TopConnectorPictureUploadRequest import TopConnectorPictureUploadRequest
from seven_top.top.api.rest.CrmGroupMoveRequest import CrmGroupMoveRequest
from seven_top.top.api.rest.OpencrmPointSendRequest import OpencrmPointSendRequest
from seven_top.top.api.rest.PictureTokenRequest import PictureTokenRequest
from seven_top.top.api.rest.OpencrmSmsSingleSendRequest import OpencrmSmsSingleSendRequest
from seven_top.top.api.rest.OpencrmShortmessageSendRequest import OpencrmShortmessageSendRequest
from seven_top.top.api.rest.OpencrmEventreportGetRequest import OpencrmEventreportGetRequest
from seven_top.top.api.rest.OpencrmSmsUnsubscribeQueryRequest import OpencrmSmsUnsubscribeQueryRequest
from seven_top.top.api.rest.PictureCategoryAddRequest import PictureCategoryAddRequest
from seven_top.top.api.rest.TopConnectorEventPublishRequest import TopConnectorEventPublishRequest
from seven_top.top.api.rest.OpencrmCrowdinstLiteCreateRequest import OpencrmCrowdinstLiteCreateRequest
from seven_top.top.api.rest.OpencrmCrowdGetRequest import OpencrmCrowdGetRequest
from seven_top.top.api.rest.OpencrmSellerBlacklistQueryRequest import OpencrmSellerBlacklistQueryRequest
from seven_top.top.api.rest.OpencrmCtagUpdateRequest import OpencrmCtagUpdateRequest
from seven_top.top.api.rest.OpencrmMexRightUpdateRequest import OpencrmMexRightUpdateRequest
from seven_top.top.api.rest.FuwuPurchaseOrderPayRequest import FuwuPurchaseOrderPayRequest
from seven_top.top.api.rest.PictureUpdateRequest import PictureUpdateRequest
from seven_top.top.api.rest.OpencrmCommercialRelationCloseRequest import OpencrmCommercialRelationCloseRequest
from seven_top.top.api.rest.OpencrmTagGetRequest import OpencrmTagGetRequest
from seven_top.top.api.rest.OpencrmStrategyListRequest import OpencrmStrategyListRequest
from seven_top.top.api.rest.TmallCrmMemberFrontUnbindPrivyRequest import TmallCrmMemberFrontUnbindPrivyRequest
from seven_top.top.api.rest.OpencrmCversionCardtplUpdateRequest import OpencrmCversionCardtplUpdateRequest
from seven_top.top.api.rest.TopEventPublishRequest import TopEventPublishRequest
from seven_top.top.api.rest.OpencrmCrowdUploadAddRequest import OpencrmCrowdUploadAddRequest
from seven_top.top.api.rest.CrmMembersGroupBatchaddPrivyRequest import CrmMembersGroupBatchaddPrivyRequest
from seven_top.top.api.rest.TmallCrmMemberFrontUnbindRequest import TmallCrmMemberFrontUnbindRequest
from seven_top.top.api.rest.OpencrmCrowdUploadUpdateRequest import OpencrmCrowdUploadUpdateRequest
from seven_top.top.api.rest.CrmMembersIncrementGetPrivyRequest import CrmMembersIncrementGetPrivyRequest
from seven_top.top.api.rest.PicturePicturesGetRequest import PicturePicturesGetRequest
from seven_top.top.api.rest.OpencrmSmsCardossQueryRequest import OpencrmSmsCardossQueryRequest
from seven_top.top.api.rest.TmcQueueGetRequest import TmcQueueGetRequest
from seven_top.top.api.rest.OpencrmGradeUpdateRequest import OpencrmGradeUpdateRequest
from seven_top.top.api.rest.OpencrmCrowdUploadFinishRequest import OpencrmCrowdUploadFinishRequest
from seven_top.top.api.rest.OpencrmNodereportGetbcRequest import OpencrmNodereportGetbcRequest
from seven_top.top.api.rest.TopEventSubscriptionQueryRequest import TopEventSubscriptionQueryRequest
from seven_top.top.api.rest.OpencrmRuleinstanceBatchaddRequest import OpencrmRuleinstanceBatchaddRequest
from seven_top.top.api.rest.OpencrmCversionDigtplCreateupdateRequest import OpencrmCversionDigtplCreateupdateRequest
from seven_top.top.api.rest.JushitaJdpUsersGetRequest import JushitaJdpUsersGetRequest
from seven_top.top.api.rest.OpencrmCrowdAlgorithmCheckRequest import OpencrmCrowdAlgorithmCheckRequest
from seven_top.top.api.rest.OpencrmStrategyInstConfigProcessRequest import OpencrmStrategyInstConfigProcessRequest
from seven_top.top.api.rest.OpencrmSmsQresultRequest import OpencrmSmsQresultRequest
from seven_top.top.api.rest.OpencrmTemplateQueryRequest import OpencrmTemplateQueryRequest
from seven_top.top.api.rest.OpencrmTagsQueryRequest import OpencrmTagsQueryRequest
from seven_top.top.api.rest.OpencrmSmsservicestatusUpdateRequest import OpencrmSmsservicestatusUpdateRequest
from seven_top.top.api.rest.OpencrmMemadLevQueryRequest import OpencrmMemadLevQueryRequest
from seven_top.top.api.rest.TmcUserTopicsGetRequest import TmcUserTopicsGetRequest
from seven_top.top.api.rest.TmallMeiCrmCallbackPointChangeRequest import TmallMeiCrmCallbackPointChangeRequest
from seven_top.top.api.rest.OpencrmCrowdinstFilterRequest import OpencrmCrowdinstFilterRequest
from seven_top.top.api.rest.OpencrmStrategyInstListRequest import OpencrmStrategyInstListRequest
from seven_top.top.api.rest.OpencrmIsvtagUploadRequest import OpencrmIsvtagUploadRequest
from seven_top.top.api.rest.JushitaJdpUserDeleteRequest import JushitaJdpUserDeleteRequest
from seven_top.top.api.rest.OpencrmCrowdCoverageCountRequest import OpencrmCrowdCoverageCountRequest
from seven_top.top.api.rest.CrmGroupDeleteRequest import CrmGroupDeleteRequest
from seven_top.top.api.rest.OpencrmStrategyInstConfigGetRequest import OpencrmStrategyInstConfigGetRequest
from seven_top.top.api.rest.PictureDeleteRequest import PictureDeleteRequest
from seven_top.top.api.rest.CrmMembersGroupBatchaddRequest import CrmMembersGroupBatchaddRequest
from seven_top.top.api.rest.OpencrmTmcsSyncRequest import OpencrmTmcsSyncRequest
from seven_top.top.api.rest.OpencrmDigitalSmsCrowdSendRequest import OpencrmDigitalSmsCrowdSendRequest
from seven_top.top.api.rest.CrmMemberGroupGetRequest import CrmMemberGroupGetRequest
from seven_top.top.api.rest.OpenmemberSellerinfoQueryRequest import OpenmemberSellerinfoQueryRequest
from seven_top.top.api.rest.TmallMeiCrmMemberSyncPrivyRequest import TmallMeiCrmMemberSyncPrivyRequest
from seven_top.top.api.rest.OpencrmSmsCrowdPostRequest import OpencrmSmsCrowdPostRequest
from seven_top.top.api.rest.AlibabaAliqinFcDigitalsmsCreatetemplateRequest import AlibabaAliqinFcDigitalsmsCreatetemplateRequest
from seven_top.top.api.rest.OpencrmSmgStrategyQueryRequest import OpencrmSmgStrategyQueryRequest
from seven_top.top.api.rest.OpencrmCrowdDeleteRequest import OpencrmCrowdDeleteRequest
from seven_top.top.api.rest.OpencrmActivityCreateupdateRequest import OpencrmActivityCreateupdateRequest
from seven_top.top.api.rest.OpencrmTemplateQueryPaasRequest import OpencrmTemplateQueryPaasRequest
from seven_top.top.api.rest.FuwuSpConfirmApplyRequest import FuwuSpConfirmApplyRequest
from seven_top.top.api.rest.OpencrmAllDomainCrowdUploadRequest import OpencrmAllDomainCrowdUploadRequest
from seven_top.top.api.rest.OpencrmCrowdanalysisUpdateRequest import OpencrmCrowdanalysisUpdateRequest
from seven_top.top.api.rest.OpencrmCouponquotaGetRequest import OpencrmCouponquotaGetRequest
from seven_top.top.api.rest.OpencrmCrowdinstsGatherRequest import OpencrmCrowdinstsGatherRequest
from seven_top.top.api.rest.OpencrmSellerOrderActivateStatusQueryRequest import OpencrmSellerOrderActivateStatusQueryRequest
from seven_top.top.api.rest.OpencrmAnalysisreportGetRequest import OpencrmAnalysisreportGetRequest
from seven_top.top.api.rest.OpencrmTagsCoverageCountRequest import OpencrmTagsCoverageCountRequest
from seven_top.top.api.rest.OpencrmExtStrategyGenerateRequest import OpencrmExtStrategyGenerateRequest
from seven_top.top.api.rest.FuwuSkuGetRequest import FuwuSkuGetRequest
from seven_top.top.api.rest.OpencrmCrowdAddRequest import OpencrmCrowdAddRequest
from seven_top.top.api.rest.OpencrmCtagUploadSingleCountRangeRequest import OpencrmCtagUploadSingleCountRangeRequest
from seven_top.top.api.rest.PictureIsreferencedGetRequest import PictureIsreferencedGetRequest
from seven_top.top.api.rest.OpencrmActivitydetailCreateupdateRequest import OpencrmActivitydetailCreateupdateRequest
from seven_top.top.api.rest.OpencrmCversionTemplateQueryRequest import OpencrmCversionTemplateQueryRequest
from seven_top.top.api.rest.OpencrmCversionDigtplQueryRequest import OpencrmCversionDigtplQueryRequest
from seven_top.top.api.rest.CrmMemberinfoUpdatePrivyRequest import CrmMemberinfoUpdatePrivyRequest
# CRM接口